@@ -7,12 +7,20 @@ from .constants import CLI_DATE_FORMAT
 from .chinadaily import download
 
 
+# todo(@yarving): auto generate version number
+def get_version():
+    """Get version number"""
+    return '0.1.6'
+
+
 def get_parser():
-    """Ger argument parser"""
+    """Get argument parser"""
     parser = argparse.ArgumentParser("China Daily newspaper downloader")
-    parser.add_argument('date', nargs='?',
+    parser.add_argument('date', nargs='*',
                         type=lambda s: datetime.strptime(s, CLI_DATE_FORMAT),
-                        help="specified date, default as today")
+                        help="specified dates(default as today), multiple dates separated by blank")
+    parser.add_argument('-v', '--version',
+                        action='version', version=get_version(), help='Display version')
 
     return parser
 
@@ -22,8 +30,10 @@ def main():
     parser = get_parser()
     args = parser.parse_args()
 
-    date = args.date if args.date else datetime.now()
-    download(date)
+    dates = args.date if args.date else [datetime.now()]
+    for date in dates:
+        download(date)
+
     return 0
 
 
