@@ -20,6 +20,8 @@ class TestChinadaily(unittest.TestCase):
     def test_000_something(self):
         """Test something."""
 
+    # todo(@yarving): implement test trigger
+    @unittest.skipUnless(os.getenv('download'), "skip download due to network slowing")
     def test_download(self):
         """Test download"""
         now = datetime.now()
